Skip to contents

Returns overlap fractions per histone mark against a reference database, allowing comparison of which marks best predict regions in the reference. Supports any database in database, not just FANTOM.

Usage

benchmark_enhancer_predictor(
  database,
  histone = "h3k4me1",
  curated_database = "fantom"
)

Arguments

database

epiRomics class database containing all data initially loaded

histone

name or vector of histone mark(s), must match a name entry in meta(database), default set to h3k4me1

curated_database

database to test histone marks against, must match a name entry in meta(database), default set to fantom

Value

Variable of class dataframe further exploring top histone marks that may determine enhancer regions

Examples

db <- make_example_database()
## Use h3k27ac as the curated reference; compare h3k4me1 against it
test <- benchmark_enhancer_predictor(
  db,
  histone = "h3k4me1",
  curated_database = "h3k27ac"
)
test
#>   Histone_Mark Fraction_of_Overlap
#> 1      h3k4me1                0.75