Skip to contents

These functions have been renamed in epiRomics 0.99.1 to follow Bioconductor naming conventions. They remain as thin wrappers that emit a one-time rename notice and forward to the new name. They will be removed in the next release.

Usage

epiRomics_build_dB(...)

epiRomics_cache_data(...)

epiRomics_cache_path(...)

epiRomics_has_cache(...)

epiRomics_chromatin_states(...)

epiRomics_chromatin_states_categories(...)

epiRomics_enhanceosome(...)

epiRomics_enhancer_predictor_to_ref(...)

epiRomics_enhancers_co_marks(...)

epiRomics_enhancers_filter(...)

epiRomics_filter_accessible(...)

epiRomics_annotate_putative(...)

epiRomics_putative_enhancers(...)

epiRomics_quick_view(...)

epiRomics_regions_of_interest(...)

epiRomics_tf_cobinding(...)

epiRomics_tf_overlap(...)

epiRomics_track_layer(...)

epiRomics_track_layer_fast(...)

epiRomics_track_layer_gene(...)

Arguments

...

Arguments forwarded to the replacement function.