Skip to contents

Identifies putative enhancer regions utilizing select histone mark co-occurrence

Usage

find_enhancers_by_comarks(
  database,
  histone_mark_1 = "h3k4me1",
  histone_mark_2 = "h3k27ac"
)

Arguments

database

epiRomics class database containing all data initially loaded

histone_mark_1

name of first histone mark, must match a name entry in meta(database), default set to h3k4me1

histone_mark_2

name of second histone mark, must match a name entry in meta(database), default set to h3k27ac

Value

Variable of class epiRomics further exploring candidate enhancer regions identified after histone integration

Examples

db <- make_example_database()
enhancers <- find_enhancers_by_comarks(db)
length(annotations(enhancers))
#> [1] 3