Skip to contents

Returns the path to previously cached example data, or NULL if the data has not been downloaded yet.

Usage

get_cache_path()

Value

Character string path, or NULL if data is not cached.

See also

Examples

cache_path <- get_cache_path()
if (!is.null(cache_path)) {
  list.files(cache_path)
}