Skip to contents

Tests whether the example data archive has been previously downloaded and extracted using cache_data. This function never triggers a download.

Usage

has_cache()

Value

Logical; TRUE if the data is cached and extracted, FALSE otherwise.

See also

cache_data to download the data.

Examples

## Check data availability (does NOT download)
if (has_cache()) {
  message("Example data is available locally.")
} else {
  message("Run cache_data() to download example data.")
}
#> Run cache_data() to download example data.