Identifies putative enhancer regions utilizing select histone mark co-occurrence
Source:R/enhancers.R
find_enhancers_by_comarks.RdIdentifies putative enhancer regions utilizing select histone mark co-occurrence
Value
Variable of class epiRomics further exploring candidate enhancer regions identified after histone integration
Examples
db <- make_example_database()
enhancers <- find_enhancers_by_comarks(db)
length(annotations(enhancers))
#> [1] 3