Returns the path to previously cached example data, or NULL
if the data has not been downloaded yet.
Examples
cache_path <- get_cache_path()
if (!is.null(cache_path)) {
list.files(cache_path)
}
Returns the path to previously cached example data, or NULL
if the data has not been downloaded yet.
cache_path <- get_cache_path()
if (!is.null(cache_path)) {
list.files(cache_path)
}