Tests whether the example data archive has been previously downloaded
and extracted using cache_data. This function
never triggers a download.
See also
cache_data to download the data.
Tests whether the example data archive has been previously downloaded
and extracted using cache_data. This function
never triggers a download.
cache_data to download the data.